@@ -57,7 +57,10 @@
 //!
 //! - `rustc-serialize`
 //!   - Optional, compatible with Rust stable
-//!   - Enables serialization support
+//!   - Enables serialization support for rustc-serialize 0.3
+//! - `serde`
+//!   - Optional, compatible with Rust stable
+//!   - Enables serialization support for serde 0.8
 //! - `blas`
 //!   - Optional and experimental, compatible with Rust stable
 //!   - Enable transparent BLAS support for matrix multiplication. Pluggable
@@ -114,6 +117,8 @@ pub use shape_builder::{ ShapeBuilder };
 mod arraytraits;
 #[cfg(feature = "serde")]
 mod arrayserialize;
+#[cfg(feature = "serde")]
+mod arraydeserialize;
 mod arrayformat;
 mod data_traits;
 
